@@ -6,6 +6,7 @@ import logging
 from operator import attrgetter
 
 import libcloud.common.types as cloud_types
+from libcloud.common.exceptions import BaseHTTPError
 from libcloud.compute.base import NodeDriver, NodeAuthSSHKey
 
 from ...config import NETWORK_ERRORS
@@ -210,6 +211,11 @@ class BaseComputeNodeDriver(RetryMixin):
         # libcloud compute drivers typically raise bare Exceptions to
         # represent API errors.  Return True for any exception that is
         # exactly an Exception, or a better-known higher-level exception.
+        if (type(exception) is BaseHTTPError and
+            exception.message and
+            (exception.message.startswith("InvalidInstanceID.NotFound") or
+             exception.message.startswith("InstanceLimitExceeded"))):
+            return True
         return (isinstance(exception, cls.CLOUD_ERRORS) or
                 type(exception) is Exception)
 
